function [Year, MfrName, CarLine, Car_Truck, EngDisp, Police, RatedHP, Transmission, Drive, Weight, Comp, AxleRatio, EVSpeedRatio, AC, PRP, FuelType, City_Highway, HC, CO, CO2, NOX, MPG, Valves_Cyl, CoastDownTime] = importfile(workbookFile, sheetName, dataLines)
%IMPORTFILE Import data from a spreadsheet
%  [YEAR, MFRNAME, CARLINE, CAR_TRUCK, ENGDISP, POLICE, RATEDHP,
%  TRANSMISSION, DRIVE, WEIGHT, COMP, AXLERATIO, EVSPEEDRATIO, AC, PRP,
%  FUELTYPE, CITY_HIGHWAY, HC, CO, CO2, NOX, MPG, VALVES_CYL,
%  COASTDOWNTIME] = IMPORTFILE(FILE) reads data from the first worksheet
%  in the Microsoft Excel spreadsheet file named FILE.  Returns the data
%  as column vectors.
%
%  [YEAR, MFRNAME, CARLINE, CAR_TRUCK, ENGDISP, POLICE, RATEDHP,
%  TRANSMISSION, DRIVE, WEIGHT, COMP, AXLERATIO, EVSPEEDRATIO, AC, PRP,
%  FUELTYPE, CITY_HIGHWAY, HC, CO, CO2, NOX, MPG, VALVES_CYL,
%  COASTDOWNTIME] = IMPORTFILE(FILE, SHEET) reads from the specified
%  worksheet.
%
%  [YEAR, MFRNAME, CARLINE, CAR_TRUCK, ENGDISP, POLICE, RATEDHP,
%  TRANSMISSION, DRIVE, WEIGHT, COMP, AXLERATIO, EVSPEEDRATIO, AC, PRP,
%  FUELTYPE, CITY_HIGHWAY, HC, CO, CO2, NOX, MPG, VALVES_CYL,
%  COASTDOWNTIME] = IMPORTFILE(FILE, SHEET, DATALINES) reads from the
%  specified worksheet for the specified row interval(s). Specify
%  DATALINES as a positive scalar integer or a N-by-2 array of positive
%  scalar integers for dis-contiguous row intervals.
%
%  Example:
%  [Year, MfrName, CarLine, Car_Truck, EngDisp, Police, RatedHP, Transmission, Drive, Weight, Comp, AxleRatio, EVSpeedRatio, AC, PRP, FuelType, City_Highway, HC, CO, CO2, NOX, MPG, Valves_Cyl, CoastDownTime] = importfile("D:\Victoria\WSE\AnalisisVisualizacionDatos\Combustible.xlsx", "Sheet1", [1, 5256]);
%
%  See also READTABLE.
%
% Auto-generated by MATLAB on 12-Jul-2021 09:59:22

%% Input handling

% If no sheet is specified, read first sheet
if nargin == 1 || isempty(sheetName)
    sheetName = 1;
end

% If row start and end points are not specified, define defaults
if nargin <= 2
    dataLines = [1, 5256];
end

%% Set up the Import Options and import the data
opts = spreadsheetImportOptions("NumVariables", 24);

% Specify sheet and range
opts.Sheet = sheetName;
opts.DataRange = "A" + dataLines(1, 1) + ":X" + dataLines(1, 2);

% Specify column names and types
opts.VariableNames = ["Year", "MfrName", "CarLine", "Car_Truck", "EngDisp", "Police", "RatedHP", "Transmission", "Drive", "Weight", "Comp", "AxleRatio", "EVSpeedRatio", "AC", "PRP", "FuelType", "City_Highway", "HC", "CO", "CO2", "NOX", "MPG", "Valves_Cyl", "CoastDownTime"];
opts.VariableTypes = ["double", "categorical", "categorical", "categorical", "double", "categorical", "double", "categorical", "categorical", "double", "double", "double", "double", "categorical", "double", "double", "categorical", "double", "double", "double", "double", "double", "double", "double"];

% Specify variable properties
opts = setvaropts(opts, ["MfrName", "CarLine", "Car_Truck", "Police", "Transmission", "Drive", "AC", "City_Highway"], "EmptyFieldRule", "auto");

% Import the data
tbl = readtable(workbookFile, opts, "UseExcel", false);

for idx = 2:size(dataLines, 1)
    opts.DataRange = "A" + dataLines(idx, 1) + ":X" + dataLines(idx, 2);
    tb = readtable(workbookFile, opts, "UseExcel", false);
    tbl = [tbl; tb]; %#ok<AGROW>
end

%% Convert to output type
Year = tbl.Year;
MfrName = tbl.MfrName;
CarLine = tbl.CarLine;
Car_Truck = tbl.Car_Truck;
EngDisp = tbl.EngDisp;
Police = tbl.Police;
RatedHP = tbl.RatedHP;
Transmission = tbl.Transmission;
Drive = tbl.Drive;
Weight = tbl.Weight;
Comp = tbl.Comp;
AxleRatio = tbl.AxleRatio;
EVSpeedRatio = tbl.EVSpeedRatio;
AC = tbl.AC;
PRP = tbl.PRP;
FuelType = tbl.FuelType;
City_Highway = tbl.City_Highway;
HC = tbl.HC;
CO = tbl.CO;
CO2 = tbl.CO2;
NOX = tbl.NOX;
MPG = tbl.MPG;
Valves_Cyl = tbl.Valves_Cyl;
CoastDownTime = tbl.CoastDownTime;
end